@@ -9,24 +9,24 @@ def split_annotations_edf2hdf(edf_path:str,
     export_path:str,
     is_overwrite:bool = False,
     is_groupby:bool = False,
+    min_signal_size:Optional[int] = None,
     annotation_filter_func:Optional[Callable[[str],bool]] = None,
     label_filter_func:Optional[Callable[[str],bool]] = None,
     before_preprocessing_func:Optional[Callable[[list[np.ndarray]],Any]] = None,
-    split_signals_func:Optional[Callable[[Any,edf.GetAnnotationType,Optional[edf.GetAnnotationType]],np.ndarray]] = None,
-    after_preprocessing_func:Callable[[np.ndarray,str],np.ndarray] = None,
-    end_marker_name:Optional[str] = "__End__"):
+    split_signals_func:Optional[Callable[[Any,edf.GetAnnotationType],np.ndarray]] = None,
+    after_preprocessing_func:Callable[[np.ndarray,str],np.ndarray] = None):
     """Split the edf file by annotation and save it in the hdf file.
      Args:
         edf_path : read edf path
         export_path : write hdf path
         is_overwrite : overwrite the edf file
         is_groupby : grouping
+        min_signal_size(int?) : Minimum signal size. if not met, exclude.
         annotation_filter_func(function[[str],bool]?) : annotation filter
         label_filter_func(function[[str],bool]?) : label filter
         before_preprocessing_func(function?) : before preprocessing function (split_signals_func must also be used when changing the signal length)
         split_signals_func(function?) : signal split function
         after_preprocessing_func(function[[signals,label],ndarray]?) : Preprocess the signals split by annotations. ndarray : ch × annotation range 
-        end_marker_name(str?) : annotation of marker_name end time
     """
     with pyedflib.EdfReader(edf_path) as edf_reader:
         signals = edf.get_all_signals(edf_reader)
@@ -44,18 +44,17 @@ def split_annotations_edf2hdf(edf_path:str,
         annotations =  edf.get_annotations(edf_reader)
         split_signals:list[tuple[str,np.ndarray,str,dict]] = [] #[(annotation name,signal,label,attrs)]
         for idx,ann in enumerate(annotations):
-            next_ann:Optional[edf.GetAnnotationType] = annotations[idx + 1] if idx + 1 < len(annotations) else None
-            ann_name,ann_time,_,ann_idx = ann
-            if ann_name == end_marker_name:
-                continue
-            split_ann_name = ann_name.split("_")
-            ann_group_name = "_".join(split_ann_name[:-1]) if len(split_ann_name) > 1 else ann_name
-            label= split_ann_name[-1] if len(split_ann_name) > 1 else ""
+            ann_name,_,_,ann_idx = ann
+            split_ann_names = ann_name.split("__")
+            label= split_ann_names[-1] if len(split_ann_names) > 2 else ""
+            offset_end_idx = int(split_ann_names[0]) if len(split_ann_names) > 1 else 0
+            ann_group_name = split_ann_names[1 if len(split_ann_names) > 1 else 0]
             if split_signals_func is None:
                 signals = np.array(signals)
-                split_signals.append((ann_group_name,signals[:,ann_idx:(next_ann[3] if next_ann is not None else signals.shape[1])],label,common_attrs))
+                s = signals[:,ann_idx:(ann_idx + offset_end_idx)]
             else:
-                s = split_signals_func(signals,ann,next_ann)
+                s = split_signals_func(signals,ann)
+            if min_signal_size is None or s.shape[1] >= min_signal_size:
                 split_signals.append((ann_group_name,s,label,common_attrs))
         if annotation_filter_func is not None:
             split_signals =  [ss for ss in split_signals if annotation_filter_func(ss[0])]
